<?php

namespace EventPortal\Domain\Component;

use Illuminate\Support\Arr;

class Value
{
    /**
     * @param array|string|bool $value
     * @return array|string
     */
    public static function get($value, ?bool $nullToFalse = false)
    {
        if (static::isArray($value)) {
            return Arr::get($value, 'label');
        }

        if (static::isMultiLevelArray($value)) {
            $value = Arr::pluck($value, 'label');

            return implode(', ', $value);
        }

        if (static::isTrue($value)) {
            return 'True';
        }

        if (static::isFalse($value) || static::wantsNullAsFalse($value, $nullToFalse)) {
            return 'False';
        }

        if (static::isJson($value)) {
            return self::get(json_decode($value, true));
        }

        return $value;
    }

    /**
     * @param mixed $value
     */
    public static function isArray($value): bool
    {
        return is_array($value) && Arr::has($value, 'label');
    }

    /**
     * @param mixed $value
     */
    public static function isMultiLevelArray($value): bool
    {
        return is_array($value) && is_array(Arr::first($value));
    }

    /**
     * @param mixed $value
     */
    public static function isTrue($value): bool
    {
        return is_bool($value) && $value === true;
    }

    /**
     * @param mixed $value
     */
    public static function isJson($value): bool
    {
        $json = json_decode($value);

        return $json && $value !== $json;
    }

    /**
     * @param mixed $value
     */
    private static function isFalse($value): bool
    {
        return is_bool($value) && $value === false;
    }

    /**
     * @param mixed $value
     */
    private static function wantsNullAsFalse($value, ?bool $nullToFalse): bool
    {
        return $nullToFalse && $value === null;
    }
}
