<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Route;

class EventStatusMiddlewareTest extends TestCase
{
    use RefreshDatabase;

    /** @test */
    public function cannot_view_event_if_event_status_draft(): void
    {
        $event = factory(Event::class)->state('draft')->create();
        $this->get(route('test.event.route', $event))->assertStatus(401);
    }

    /** @test */
    public function cannot_view_event_if_event_status_archived(): void
    {
        $event = factory(Event::class)->state('archived')->create();
        $this->get(route('test.event.route', $event))->assertStatus(401);
    }

    /** @test */
    public function can_view_event_if_status_is_published(): void
    {
        $event = factory(Event::class)->state('published')->create();
        $this->get(route('test.event.route', $event))->assertStatus(302);
    }

    /** @test */
    public function can_view_event_if_status_is_post(): void
    {
        $event = factory(Event::class)->state('post')->create();
        $this->get(route('test.event.route', $event))->assertStatus(302);
    }

    /** @test */
    public function can_view_event_if_status_is_cancelled(): void
    {
        $event = factory(Event::class)->state('cancelled')->create();
        $this->get(route('test.event.route', $event))->assertStatus(302);
    }

    public function setUp(): void
    {
        parent::setUp();

        Route::get(
            'intest/{event}',
            function (Event $event): RedirectResponse {
                return redirect()->back()->with('success', 'yass queen');
            }
        )->name('test.event.route')
            ->middleware(['web', 'check-event-status']);
    }
}
