<?php

namespace EventPortal\Tests\Unit\Event\Form\Handlers;

use EventPortal\Domain\Event\Form\Enums\FormType;
use EventPortal\Domain\Event\Form\Handlers\CreateForm;
use EventPortal\Domain\Event\Form\Models\Form;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Payload;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Pipeline\Pipeline;

class CreateFormTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_form(): void
    {
        $event = factory(Event::class)->create();

        $payload = Payload::make([
            'name' => 'Example',
            'type' => FormType::Registration()->getValue(),
        ])->withContext(['event' => $event])->withModel(new Form);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateForm])
            ->thenReturn();

        $this->assertDatabaseHas('forms', [
            'name' => 'Example',
            'type' => FormType::Registration()->getValue(),
        ]);
    }

    /** @test **/
    public function event_is_added_to_context(): void
    {
        $model = factory(Form::class)->create();

        $payload = Payload::make([
            'name' => 'Example',
            'type' => FormType::Registration()->getValue(),
        ])->withContext(['event' => $model->event])->withModel($model);

        app(Pipeline::class)
            ->send($payload)
            ->through([new CreateForm])
            ->thenReturn();

        $this->assertInstanceOf(Event::class, $payload->getContext('event'));
    }
}
